@@ -1,9 +1,13 @@
-use strict;
+package Dist::Zilla::Path 6.025;
+# ABSTRACT: a helper to get Path::Tiny objects
+
+# BEGIN BOILERPLATE
+use v5.20.0;
 use warnings;
 use utf8;
-
-package Dist::Zilla::Path 6.010;
-# ABSTRACT: a helper to get Path::Tiny objects
+no feature 'switch';
+use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
+# END BOILERPLATE
 
 use parent 'Path::Tiny';
 
@@ -14,6 +18,8 @@ use Sub::Exporter -setup => {
   groups  => { default => [ qw( path ) ] },
 };
 
+use namespace::autoclean -except => 'import';
+
 sub path {
   my ($thing, @rest) = @_;
 
@@ -33,7 +39,9 @@ sub file {
   my ($self, @file) = @_;
 
   my ($package, $pmfile, $line) = caller;
-  unless ($warned{ $pmfile, $line }++) {
+
+  my $key = join qq{\0}, $pmfile, $line;
+  unless ($warned{ $key }++) {
     Carp::carp("->file called on a Dist::Zilla::Path object; this will cease to work in Dist::Zilla v7; downstream code should be updated to use Path::Tiny API, not Path::Class");
   }
 
@@ -62,15 +70,27 @@ Dist::Zilla::Path - a helper to get Path::Tiny objects
 
 =head1 VERSION
 
-version 6.010
+version 6.025
+
+=head1 PERL VERSION
+
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
