@@ -1,10 +1,18 @@
-package Dist::Zilla::Plugin::MetaJSON 6.010;
+package Dist::Zilla::Plugin::MetaJSON 6.025;
 # ABSTRACT: produce a META.json
 
 use Moose;
 with 'Dist::Zilla::Role::FileGatherer';
 use Moose::Util::TypeConstraints;
 
+# BEGIN BOILERPLATE
+use v5.20.0;
+use warnings;
+use utf8;
+no feature 'switch';
+use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
+# END BOILERPLATE
+
 use namespace::autoclean;
 
 #pod =head1 DESCRIPTION
@@ -122,7 +130,7 @@ Dist::Zilla::Plugin::MetaJSON - produce a META.json
 
 =head1 VERSION
 
-version 6.010
+version 6.025
 
 =head1 DESCRIPTION
 
@@ -131,6 +139,18 @@ This plugin will add a F<META.json> file to the distribution.
 This file is meant to replace the old-style F<META.yml>.  For more information
 on this file, see L<Module::Build::API> and L<CPAN::Meta>.
 
+=head1 PERL VERSION
+
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 filename
@@ -161,11 +181,11 @@ L<CPAN::Meta::Spec>, L<JSON::MaybeXS>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
